@@ -403,7 +403,7 @@ if (cacti_sizeof($parms)) {
 				print "ERROR: number of --snmp-field ($nbSnmpFields) and --snmp-value-regex ($nbSnmpValuesRegex) does not match\n";
 				exit(1);
 			}
-		} else {
+		} elseif (!$listSNMPValues) {
 			print "ERROR: You must supply a --snmp-value or --snmp-value-regex option with --snmp-field\n";
 			exit(1);
 		}
@@ -634,10 +634,10 @@ if (cacti_sizeof($parms)) {
 				$req  .= ' AND snmp_index IN (
 					SELECT DISTINCT snmp_index FROM host_snmp_cache WHERE host_id=' . $host_id . ' AND field_name = ' . db_qstr($snmpField);
 
-				if (cacti_sizeof($dsGraph['snmpValue'])) {
+				if (isset($dsGraph['snmpValue'][$index_snmp_filter])) {
 					$req .= ' AND field_value = ' . db_qstr($dsGraph['snmpValue'][$index_snmp_filter]). ')';
-				} else {
-					$req .= ' AND field_value LIKE "%' . addslashes($dsGraph['snmpValueRegex'][$index_snmp_filter]) . '%")';
+				} elseif (isset($dsGraph['snmpValueRegex'][$index_snmp_filter])) {
+					$req .= ' AND field_value REGEXP "' . addslashes($dsGraph['snmpValueRegex'][$index_snmp_filter]) . '")';
 				}
 
 				$index_snmp_filter++;
