@@ -119,6 +119,7 @@ $cacti_version_codes = array(
 	'1.2.4'  => '0102',
 	'1.2.5'  => '0102',
 	'1.2.6'  => '0102',
+	'1.2.7'  => '0102',
 );
 
 $messages = array(
@@ -871,7 +872,7 @@ if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 			),
 		__('Create') => array(
 			'graphs_new.php' => __('New Graphs'),
-			'host.php?action=edit' => __('New Device')
+			'host.php?action=edit&create=true' => __('New Device')
 			),
 		__('Management') => array(
 			'host.php'             => __('Devices'),
