@@ -447,3 +447,8 @@ define('GRAPH_SOURCE_PLAIN', 0);
 define('GRAPH_SOURCE_DATA_QUERY', 1);
 define('GRAPH_SOURCE_TEMPLATE', 2);
 define('GRAPH_SOURCE_AGGREGATE', 3);
+
+define('CACTI_LANGUAGE_HANDLER_NONE', 0);
+define('CACTI_LANGUAGE_HANDLER_PHPGETTEXT', 1);
+define('CACTI_LANGUAGE_HANDLER_OSCAROTERO', 2);
+define('CACTI_LANGUAGE_HANDLER_MOTRANSLATOR', 3);
