@@ -36,6 +36,7 @@ $lang2locale = get_list_of_locales();
 
 /* use a fallback if i18n is disabled (default) */
 if (!read_config_option('i18n_language_support') && read_config_option('i18n_language_support') != '') {
+	l10n_debug("load_fallback_procedure(1)");
 	load_fallback_procedure();
 	return;
 }
@@ -71,6 +72,9 @@ if ($user_locale !== false && $user_locale !== '') {
 }
 
 /* define the path to the language file */
+l10n_debug("search(1): " . $config['base_path'] . '/locales/LC_MESSAGES/' . $cacti_locale . '.mo');
+l10n_debug("search(2): " . $config['base_path'] . '/locales/LC_MESSAGES/' . $lang2locale[$cacti_locale]['filename'] . '.mo');
+
 if (file_exists($config['base_path'] . '/locales/LC_MESSAGES/' . $cacti_locale . '.mo')) {
 	$path2catalogue = $config['base_path'] . '/locales/LC_MESSAGES/' . $cacti_locale . '.mo';
 } elseif (file_exists($config['base_path'] . '/locales/LC_MESSAGES/' . $lang2locale[$cacti_locale]['filename'] . '.mo')) {
@@ -121,6 +125,7 @@ if ($cacti_locale != '') {
 if (file_exists($path2catalogue)) {
 	$cacti_textdomains['cacti']['path2catalogue'] = $path2catalogue;
 } else {
+	l10n_debug("load_fallback_procedure(2): " . $path2catalogue);
 	load_fallback_procedure();
 	return;
 }
@@ -148,40 +153,140 @@ if ($plugins && cacti_sizeof($plugins)) {
 	/* if i18n support is set to strict mode then check if all plugins support the requested language */
 	if (read_config_option('i18n_language_support') == 2) {
 		if (cacti_sizeof($plugins) != (cacti_sizeof($cacti_textdomains) - 1)) {
+			l10n_debug("load_fallback_procedure(3)");
 			load_fallback_procedure();
 			return;
 		}
 	}
 }
 
-/* load php-gettext class */
-require($config['include_path'] . '/vendor/phpgettext/streams.php');
-require($config['include_path'] . '/vendor/phpgettext/gettext.php');
+l10n_debug("require(1)");
 
-/* prefetch all language files to work in memory only,
-   die if one of the language files is corrupted */
+/* load php-gettext class if present */
 $l10n = array();
 
-foreach ($cacti_textdomains as $domain => $paths) {
+// Is the handler defined in the db?
+$l10n_handler = read_config_option('l10n_language_handler');
+
+// Is the handler defined in the config but not the db?
+if (empty($l10n_handler) && !empty($config['l10n_language_handler'])) {
+	l10n_debug('Handler: not specified in settings');
+	$l10n_handler = $config['l10n_language_handler'];
+}
+
+if (empty($l10n_handler)) {
+	l10n_debug('Handler: not specified in config, autodetection is now in progress');
+	if (file_exists($config['include_path'] . '/vendor/gettext/src/Translator.php')) {
+		$l10n_handler = CACTI_LANGUAGE_HANDLER_OSCAROTERO;
+	} elseif (file_exists($config['include_path'] . '/vendor/phpgettext/streams.php')) {
+		$l10n_handler = CACTI_LANGUAGE_HANDLER_PHPGETTEXT;
+	} elseif (file_exists($config['include_path'] . '/vendor/motanslator/src/Translator.php')) {
+		$l10n_handler = CACTI_LANGUAGE_HANDLER_MOTRANSLATOR;
+	}
+}
+
+l10n_debug("require(1): Handler $l10n_handler");
+switch ($l10n_handler) {
+	case CACTI_LANGUAGE_HANDLER_OSCAROTERO:
+		//require($config['include_path'] . '/vendor/gettext/oscarotero.php');
+		require_once($config['include_path'] . '/vendor/gettext/src/autoloader.php');
+		require_once($config['include_path'] . '/vendor/cldr-to-gettext-plural-rules/src/autoloader.php');
+		break;
+
+	case CACTI_LANGUAGE_HANDLER_PHPGETTEXT:
+		require_once($config['include_path'] . '/vendor/phpgettext/streams.php');
+		require_once($config['include_path'] . '/vendor/phpgettext/gettext.php');
+		break;
+
+	case CACTI_LANGUAGE_HANDLER_MOTRANSLATOR:
+		require_once($config['include_path'] . '/vendor/motranslator/src/Translator.php');
+		require_once($config['include_path'] . '/vendor/motranslator/src/StringReader.php');
+		break;
+
+	default:
+		$l10n_handler = CACTI_LANGUAGE_HANDLER_NONE;
+		break;
+}
+
+define('CACTI_LANGUAGE_HANDLER', $l10n_handler);
+l10n_debug("require(2): Handler " . CACTI_LANGUAGE_HANDLER);
+
+if (CACTI_LANGUAGE_HANDLER != CACTI_LANGUAGE_HANDLER_NONE) {
+	/* prefetch all language files to work in memory only,
+	   die if one of the language files is corrupted */
+
+	foreach ($cacti_textdomains as $domain => $paths) {
+		l10n_debug("load_language($domain): " .$cacti_textdomains[$domain]['path2catalogue']);
+		switch (CACTI_LANGUAGE_HANDLER) {
+			case CACTI_LANGUAGE_HANDLER_PHPGETTEXT:
+				$l10n[$domain] = load_gettext_original($domain);
+				break;
+
+			case CACTI_LANGUAGE_HANDLER_MOTRANSLATOR:
+				$l10n[$domain] = load_gettext_motranslator($domain);
+				break;
+
+			case CACTI_LANGUAGE_HANDLER_OSCAROTERO:
+				$l10n[$domain] = load_gettext_oscarotero($domain);
+				break;
+		}
+
+		if (empty($l10n[$domain])) {
+			die('Invalid language support or corrupt/missing file: ' . $cacti_textdomains[$domain]['path2catalogue'] . PHP_EOF);
+		}
+	}
+	unset($input);
+}
+
+/* load standard wrappers */
+define('CACTI_LOCALE', $cacti_locale);
+define('CACTI_COUNTRY', $cacti_country);
+define('CACTI_LANGUAGE', $lang2locale[CACTI_LOCALE]['language']);
+define('CACTI_LANGUAGE_FILE', $catalogue);
+
+function load_gettext_original($domain) {
+	global $cacti_textdomains;
+
+	l10n_debug("load_gettext_original($domain): " .$cacti_textdomains[$domain]['path2catalogue']);
 	$input = new FileReader($cacti_textdomains[$domain]['path2catalogue']);
 	if ($input == false) {
 		die('Unable to read file: ' . $cacti_textdomains[$domain]['path2catalogue'] . PHP_EOF);
 	}
 
-	$l10n[$domain] = new gettext_reader($input);
-	if ($l10n[$domain] == false) {
+	$l10n_domain = new gettext_reader($input);
+	if ($l10n_domain == false) {
 		die('Invalid language file: ' . $cacti_textdomains[$domain]['path2catalogue'] . PHP_EOF);
 	}
+	return $l10n_domain;
 }
-unset($input);
 
-/* load standard wrappers */
-load_i18n_gettext_wrappers();
+function load_gettext_motranslator($domain) {
+	global $cacti_textdomains;
 
-define('CACTI_LOCALE', $cacti_locale);
-define('CACTI_COUNTRY', $cacti_country);
-define('CACTI_LANGUAGE', $lang2locale[CACTI_LOCALE]['language']);
-define('CACTI_LANGUAGE_FILE', $catalogue);
+	l10n_debug("load_gettext_mostranslator($domain): " .$cacti_textdomains[$domain]['path2catalogue']);
+	$input = new PhpMyAdmin\MoTranslator\Translator($cacti_textdomains[$domain]['path2catalogue']);
+	if ($input == false) {
+		die('Unable to read file: ' . $cacti_textdomains[$domain]['path2catalogue'] . PHP_EOF);
+	}
+	return $input;
+}
+
+function load_gettext_oscarotero($domain) {
+	global $cacti_textdomains;
+
+	l10n_debug("load_gettext_oscarotero($domain): " .$cacti_textdomains[$domain]['path2catalogue']);
+	$input = Gettext\Translations::fromMoFile($cacti_textdomains[$domain]['path2catalogue']);
+	if ($input == false) {
+		die('Unable to read file: ' . $cacti_textdomains[$domain]['path2catalogue'] . PHP_EOF);
+	}
+
+	$l10n_domain = new Gettext\Translator();
+	$l10n_domain->loadTranslations($input);
+	if ($l10n_domain == false) {
+		die('Invalid language file: ' . $cacti_textdomains[$domain]['path2catalogue'] . PHP_EOF);
+	}
+	return $l10n_domain;
+}
 
 function apply_locale($language) {
 	global $cacti_locale, $cacti_country, $lang2locale;
@@ -270,9 +375,6 @@ function __esc_xn() {
 function load_fallback_procedure(){
 	global $cacti_textdomains, $cacti_locale, $cacti_country, $lang2locale;
 
-	/* load wrappers if native gettext is not available */
-	load_i18n_fallback_wrappers();
-
 	/* reset variables */
 	$_SESSION['sess_user_language'] = '';
 
@@ -281,218 +383,159 @@ function load_fallback_procedure(){
 	define('CACTI_COUNTRY', 'us');
 	define('CACTI_LANGUAGE', 'English');
 	define('CACTI_LANGUAGE_FILE', 'english_usa');
-
+	define('CACTI_LANGUAGE_HANDLER', CACTI_LANGUAGE_HANDLER_NONE);
 }
 
-/**
- * load_i18n_gettext_wrappers - creates all wrappers to translate strings by using php-gettext
- *
- * @return
- */
-function load_i18n_gettext_wrappers() {
-	function __gettext($text, $domain = 'cacti') {
-		global $l10n;
-		if (isset($l10n[$domain])) {
-			return __uf($l10n[$domain]->translate($text));
-		} else {
-			return __uf($text);
+function __gettext($text, $domain = 'cacti') {
+	global $l10n;
+
+	// Assume translation fails or is not defined
+	if (isset($l10n[$domain])) {
+		switch (CACTI_LANGUAGE_HANDLER) {
+			case CACTI_LANGUAGE_HANDLER_PHPGETTEXT:
+				$translated = $l10n[$domain]->translate($text);
+				break;
+
+			case CACTI_LANGUAGE_HANDLER_OSCAROTERO:
+			case CACTI_LANGUAGE_HANDLER_MOTRANSLATOR:
+				$translated = $l10n[$domain]->gettext($text);
+				break;
 		}
 	}
 
-	function __n($singular, $plural, $number, $domain = 'cacti') {
-		global $l10n;
-		if (isset($l10n[$domain])) {
-    		return __uf($l10n[$domain]->ngettext($singular, $plural, $number));
-    	} else {
-			return ($number == 1) ? __uf($singular) : __uf($plural);
-		}
+	if (!isset($translated)) {
+		$translated = $text;
+	} else {
+		l10n_debug("__gettext($domain):\n	Original: $text\n	Translated: $translated", FILE_APPEND);
 	}
 
-	function __uf($text) {
-		return str_replace('%%', '%', $text);
-	}
-
-	function __() {
-		global $l10n;
-
-		$args = func_get_args();
-		$num  = func_num_args();
-
-		/* this should not happen */
-		if ($num < 1) {
-			return false;
-
-		/* convert pure text strings */
-		} elseif ($num == 1) {
-			return __gettext($args[0]);
-
-		/* convert pure text strings by using a different textdomain */
-		} elseif ($num == 2 && isset($l10n[$args[1]]) && $args[1] != 'cacti') {
-			return __gettext($args[0], $args[1]);
-
-		/* convert stings including one or more placeholders */
-		} else {
-			/* only the last argument is allowed to initiate
-			the use of a different textdomain */
-
-			/* get gettext string */
-			if (isset($l10n[$args[$num-1]]) && $args[$num-1] != 'cacti') {
-				$args[0] = __gettext($args[0], $args[$num-1]);
-			} else {
-				$args[0] = __gettext($args[0]);
-			}
-
-			/* process return string against input arguments */
-			return __uf(call_user_func_array('sprintf', $args));
-		}
-	}
-
-	function __xn($context, $singular, $plural, $number, $domain = 'cacti') {
-		$xsingular = $context . chr(4) . $singular;
-		$xplural = $context . chr(4) . $plural;
-
-		$msgstr = __n($xsingular, $xplural, $number, $domain);
-
-		if ($number == 1 ) {
-			return ( $msgstr == $xsingular ) ? __uf($singular) : __uf($msgstr);
-		} else {
-			return ( $msgstr == $xplural ) ? __uf($plural) : __uf($msgstr);
-		}
-	}
-
-	function __x() {
-		global $l10n;
-
-		$args = func_get_args();
-		$num  = func_num_args();
-
-		/* this should never happen */
-		if ($num < 2) {
-			return false;
-		} else {
-			$context = array_shift($args);
-			$num--;
-
-			$msgid = reset($args);
-			$xmsgid = $context . chr(4) . $msgid;
-
-			$args[0] = $xmsgid;
-
-			if ($num == 1) {
-				/* pure text string without placeholders and a change of the default textdomain */
-				$msgstr = __gettext($args[0]);
-			} else {
-				/* get gettext string */
-				$msgstr = isset($l10n[$args[$num-1]]) && $args[$num-1] != 'cacti' ?
-					__gettext($args[0], $args[$num-1]) : __gettext($args[0]);
-			}
-
-			/* use the raw message id if language catalogue does not contain a context specific message string */
-			$args[0] = ( $msgstr == $xmsgid ) ? $msgid : $msgstr;
-
-			/* process return string against input arguments */
-			return __uf(call_user_func_array('sprintf', $args));
-		}
-	}
-
-	function __date($format, $timestamp = false, $domain = 'cacti') {
-		global $i18n_date_placeholders;
-
-		if (!$timestamp) {
-			$timestamp = time();
-		}
-
-		/* placeholders will allow to fill in the translated weekdays, month and so on.. */
-		$i18n_date_placeholders = array(
-			'#1' => __(date('D', $timestamp), $domain),
-			'#2' => __(date('M', $timestamp), $domain),
-			'#3' => __(date('F', $timestamp), $domain),
-			'#4' => __(date('l', $timestamp), $domain)
-		);
-
-		/* if defined exchange the format string for the configured locale */
-		$format = __gettext($format, $domain);
-
-		/* replace special date chars by placeholders */
-		$format = str_replace(array('D', 'M', 'F', 'l'), array('#1', '#2', '#3', '#4'), $format);
-
-		/* get date string included placeholders */
-		$date = date($format, $timestamp);
-
-		/* fill in specific translations */
-		$date = str_replace(array_keys($i18n_date_placeholders), array_values($i18n_date_placeholders), $date);
-
-		return __uf($date);
-	}
+	return __uf($translated);
 }
 
-/**
- * load_i18n_fallback_wrappers - creates special wrappers to leave the native language untouched
- *
- * @return
- */
-function load_i18n_fallback_wrappers() {
-	function __gettext($text, $domain = 'cacti') {
-		return __uf($text);
-	}
-
-	function __n($singular, $plural, $number, $domain = 'cacti') {
+function __n($singular, $plural, $number, $domain = 'cacti') {
+	global $l10n;
+	if (isset($l10n[$domain])) {
+		return __uf($l10n[$domain]->ngettext($singular, $plural, $number));
+	} else {
 		return ($number == 1) ? __uf($singular) : __uf($plural);
 	}
+}
 
-	function __uf($text) {
-		return str_replace('%%', '%', $text);
-	}
+function __uf($text) {
+	return str_replace('%%', '%', $text);
+}
 
-	function __() {
-		global $l10n;
+function __() {
+	global $l10n;
 
-		$args = func_get_args();
-		$num  = func_num_args();
+	$args = func_get_args();
+	$num  = func_num_args();
 
-		/* this should not happen */
-		if ($num < 1) {
-			return false;
+	/* this should not happen */
+	if ($num < 1) {
+		return false;
 
-		/* convert pure text strings */
-		} elseif ($num == 1) {
-			return __uf($args[0]);
+	/* convert pure text strings */
+	} elseif ($num == 1) {
+		return __gettext($args[0]);
 
-		/* convert pure text strings by using a different textdomain */
-		} elseif ($num == 2 && isset($l10n[$args[1]]) && $args[1] != 'cacti') {
-			return __uf($args[0]);
+	/* convert pure text strings by using a different textdomain */
+	} elseif ($num == 2 && isset($l10n[$args[1]]) && $args[1] != 'cacti') {
+		return __gettext($args[0], $args[1]);
 
-		/* convert stings including one or more placeholders */
+	/* convert stings including one or more placeholders */
+	} else {
+		/* only the last argument is allowed to initiate
+		   the use of a different textdomain */
+
+		/* get gettext string */
+		if (isset($l10n[$args[$num-1]]) && $args[$num-1] != 'cacti') {
+			$args[0] = __gettext($args[0], $args[$num-1]);
 		} else {
-			/* only the last argument is allowed to initiate
-			the use of a different textdomain */
-
-			/* process return string against input arguments */
-			return __uf(call_user_func_array('sprintf', $args));
+			$args[0] = __gettext($args[0]);
 		}
+
+		/* process return string against input arguments */
+		return __uf(call_user_func_array('sprintf', $args));
 	}
+}
 
-	function __xn($context, $singular, $plural, $number, $domain = 'cacti') {
-		return __n($singular, $plural, $number, $domain);
+function __xn($context, $singular, $plural, $number, $domain = 'cacti') {
+	$xsingular = $context . chr(4) . $singular;
+	$xplural = $context . chr(4) . $plural;
+
+	$msgstr = __n($xsingular, $xplural, $number, $domain);
+
+	if ($number == 1 ) {
+		return ( $msgstr == $xsingular ) ? __uf($singular) : __uf($msgstr);
+	} else {
+		return ( $msgstr == $xplural ) ? __uf($plural) : __uf($msgstr);
 	}
+}
 
-	function __x() {
-		$args = func_get_args();
-		$num  = func_num_args();
+function __x() {
+	global $l10n;
 
-		/* this should never happen */
-		if ($num < 2) {
-			return false;
+	$args = func_get_args();
+	$num  = func_num_args();
+
+	/* this should never happen */
+	if ($num < 2) {
+		return false;
+	} else {
+		$context = array_shift($args);
+		$num--;
+
+		$msgid = reset($args);
+		$xmsgid = $context . chr(4) . $msgid;
+
+		$args[0] = $xmsgid;
+
+		if ($num == 1) {
+			/* pure text string without placeholders and a change of the default textdomain */
+			$msgstr = __gettext($args[0]);
 		} else {
-			$context = array_shift($args);
-			return __uf(call_user_func_array('__', $args));
+			/* get gettext string */
+			$msgstr = isset($l10n[$args[$num-1]]) && $args[$num-1] != 'cacti' ?
+			__gettext($args[0], $args[$num-1]) : __gettext($args[0]);
 		}
+
+		/* use the raw message id if language catalogue does not contain a context specific message string */
+		$args[0] = ( $msgstr == $xmsgid ) ? $msgid : $msgstr;
+
+		/* process return string against input arguments */
+		return __uf(call_user_func_array('sprintf', $args));
+	}
+}
+
+function __date($format, $timestamp = false, $domain = 'cacti') {
+	global $i18n_date_placeholders;
+
+	if (!$timestamp) {
+		$timestamp = time();
 	}
 
-	function __date($format, $timestamp = false, $domain = 'cacti') {
-		if (!$timestamp) {$timestamp = time();}
-		return __uf(date($format, $timestamp));
-	}
+	/* placeholders will allow to fill in the translated weekdays, month and so on.. */
+	$i18n_date_placeholders = array(
+		'#1' => __(date('D', $timestamp), $domain),
+		'#2' => __(date('M', $timestamp), $domain),
+		'#3' => __(date('F', $timestamp), $domain),
+		'#4' => __(date('l', $timestamp), $domain)
+	);
+
+	/* if defined exchange the format string for the configured locale */
+	$format = __gettext($format, $domain);
+
+	/* replace special date chars by placeholders */
+	$format = str_replace(array('D', 'M', 'F', 'l'), array('#1', '#2', '#3', '#4'), $format);
+
+	/* get date string included placeholders */
+	$date = date($format, $timestamp);
+
+	/* fill in specific translations */
+	$date = str_replace(array_keys($i18n_date_placeholders), array_values($i18n_date_placeholders), $date);
+
+	return __uf($date);
 }
 
 /**
@@ -708,3 +751,10 @@ function get_new_user_default_language() {
 	return $accepted;
 }
 
+function l10n_debug($text, $mode = FILE_APPEND, $eol = PHP_EOL) {
+	if (is_dir('/share/')) {
+		file_put_contents('/share/i18n.log', $text . $eol, $mode);
+	} elseif (file_exists('/tmp/i18n.log')) {
+		file_put_contents('/tmp/i18n.log', $text . $eol, $mode);
+	}
+}
