@@ -30,7 +30,11 @@ api_plugin_hook('console_before');
 function render_external_links($style = 'FRONT') {
 	global $config;
 
-	$consoles = db_fetch_assoc_prepared('SELECT id, contentfile FROM external_links WHERE style = ?', array($style));
+	$consoles = db_fetch_assoc_prepared('SELECT id, contentfile
+		FROM external_links
+		WHERE enabled = "on"
+		AND style = ?', array($style));
+
 	if (cacti_sizeof($consoles)) {
 		foreach($consoles as $page) {
 			if (is_realm_allowed($page['id']+10000)) {
