@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -620,8 +620,35 @@ function is_tree_branch_empty($tree_id, $parent = 0) {
 		), 'host_id', 'host_id'
 	);
 
-	if (cacti_sizeof($hosts) && cacti_sizeof(get_allowed_devices('h.id IN(' . implode(',', $hosts) . ')'), 'description', '', -1) > 0) {
-		return false;
+	$sites = array_rekey(
+		db_fetch_assoc_prepared('SELECT site_id
+			FROM graph_tree_items
+			WHERE graph_tree_id = ?
+			AND site_id > 0
+			AND parent = ?',
+			array($tree_id, $parent)
+		), 'site_id', 'site_id'
+	);
+
+	if (!cacti_sizeof($sites)) {
+		if (cacti_sizeof($hosts) && cacti_sizeof(get_allowed_devices('h.id IN(' . implode(',', $hosts) . ')'), 'description', '', -1) > 0) {
+			return false;
+		}
+	} else {
+		$site_hosts = array();
+		foreach($sites as $site) {
+			$site_hosts += array_rekey(
+				db_fetch_assoc_prepared('SELECT id
+					FROM host
+					WHERE site_id = ?',
+					array($site)
+				), 'id', 'id'
+			);
+		}
+
+		if (cacti_sizeof($site_hosts) && cacti_sizeof(get_allowed_devices('h.id IN(' . implode(',', $site_hosts) . ')'), 'description', '', -1) > 0) {
+			return false;
+		}
 	}
 
 	$branches = db_fetch_assoc_prepared('SELECT id, graph_tree_id
@@ -652,7 +679,7 @@ function is_realm_allowed($realm) {
 			return false;
 		}
 
-		if (!user_perms_valid($_SESSION['sess_user_id'])) {
+		if (!is_user_perms_valid($_SESSION['sess_user_id'])) {
 			kill_session_var('sess_user_realms');
 			kill_session_var('sess_user_config_array');
 			kill_session_var('sess_config_array');
@@ -1093,6 +1120,7 @@ function get_allowed_graphs($sql_where = '', $order_by = 'gtg.title_cache', $lim
 
 		$graphs_sql = "SELECT gtg.local_graph_id, h.description, gt.name AS template_name,
 			gtg.title_cache, gtg.width, gtg.height, gl.snmp_index, gl.snmp_query_id,
+			IF(gl.graph_template_id=0, 0, IF(gl.snmp_query_id=0, 2, 1)) AS graph_source,
 			$sql_select
 			FROM graph_templates_graph AS gtg
 			INNER JOIN graph_local AS gl
@@ -1115,7 +1143,8 @@ function get_allowed_graphs($sql_where = '', $order_by = 'gtg.title_cache', $lim
 			) AS rower");
 	} else {
 		$graphs = db_fetch_assoc("SELECT gtg.local_graph_id, h.description, gt.name AS template_name,
-			gtg.title_cache, gtg.width, gtg.height, gl.snmp_index, gl.snmp_query_id
+			gtg.title_cache, gtg.width, gtg.height, gl.snmp_index, gl.snmp_query_id,
+			IF(gl.graph_template_id=0, 0, IF(gl.snmp_query_id=0, 2, 1)) AS graph_source
 			FROM graph_templates_graph AS gtg
 			INNER JOIN graph_local AS gl
 			ON gl.id=gtg.local_graph_id
@@ -1241,7 +1270,7 @@ function get_allowed_aggregate_graphs($sql_where = '', $order_by = 'gtg.title_ca
 		$sql_having = "HAVING $sql_having";
 
 		$graphs_sql = "SELECT DISTINCT gtg.local_graph_id, '' AS description, gt.name AS template_name,
-			gtg.title_cache, gtg.width, gtg.height, gl.snmp_index, gl.snmp_query_id,
+			gtg.title_cache, gtg.width, gtg.height, '' AS snmp_index, gl.snmp_query_id,
 			$sql_select
 			FROM graph_templates_graph AS gtg
 			INNER JOIN (
@@ -1326,7 +1355,9 @@ function get_allowed_type_hash($type, $init_where, $init_order, $limit, $item, $
 
 function prime_devices_type_cache($hash, $user) {
 	$init_rows = -1;
+
 	if (!isset($_SESSION['sess_allowed_templates'][$hash])) {
+		cacti_log('Priming \'Device\' cache', false, 'WEBUI', POLLER_VERBOSITY_HIGH);
 		$devices = get_allowed_devices('', 'description', -1, $init_rows, 0, $user);
 		set_cached_allowed_type('devices', $devices, $hash, $init_rows);
 	}
@@ -1334,7 +1365,20 @@ function prime_devices_type_cache($hash, $user) {
 
 function get_cached_allowed_type($hash, $init_rows) {
 	if ($hash !== false) {
-		cacti_log('Fetch InitRows:' . $init_rows . ', Hash:' . $hash, false, 'WEBUI', POLLER_VERBOSITY_DEBUG);
+		// verify if the user needs to reset cache
+		$last_change = read_config_option('sess_allowed_templates_lastchange', true);
+		$user_change = read_user_setting('sess_allowed_templates_lastchange', 0, true);
+
+		if ($user_change < $last_change || empty($user_change)) {
+			cacti_log('Detected need for forced template cache refresh:', false, 'WEBUI', POLLER_VERBOSITY_HIGH);
+			clear_cached_allowed_types();
+			set_user_setting('sess_allowed_templates_lastchange', time());
+
+			return array();
+		}
+
+		cacti_log('Fetch InitRows:' . $init_rows . ', Hash:' . $hash, false, 'WEBUI', POLLER_VERBOSITY_HIGH);
+
 		if (isset($_SESSION['sess_allowed_templates'][$hash]) && $init_rows == -1) {
 			return $_SESSION['sess_allowed_templates'][$hash];
 		}
@@ -1345,10 +1389,13 @@ function get_cached_allowed_type($hash, $init_rows) {
 
 function set_cached_allowed_type($type, &$items, $hash, $init_rows) {
 	if ($hash !== false && $init_rows == -1) {
-		cacti_log('Store InitRows:' . $init_rows . ', Hash:' . $hash, false, 'WEBUI', POLLER_VERBOSITY_DEBUG);
+		cacti_log('Store InitRows:' . $init_rows . ', Hash:' . $hash, false, 'WEBUI', POLLER_VERBOSITY_HIGH);
 
 		if ($type == 'devices') {
 			$_SESSION['sess_allowed_templates'][$hash] = array_rekey($items, 'id', 'id');
+
+			// Handle special case of host_id 0
+			$_SESSION['sess_allowed_templates'][$hash][0] = '0';
 		} else {
 			$_SESSION['sess_allowed_templates'][$hash] = $items;
 		}
@@ -1356,7 +1403,9 @@ function set_cached_allowed_type($type, &$items, $hash, $init_rows) {
 }
 
 function clear_cached_allowed_types() {
+	cacti_log('Killing Session Cache due to device or template change', false, 'WEBUI', POLLER_VERBOSITY_HIGH);
 	kill_session_var('sess_allowed_templates');
+	set_config_option('sess_allowed_templates_lastchange', time());
 }
 
 function get_allowed_graph_templates($sql_where = '', $order_by = 'gt.name', $limit = '', &$total_rows = 0, $user = 0, $graph_template_id = 0) {
@@ -1364,9 +1413,11 @@ function get_allowed_graph_templates($sql_where = '', $order_by = 'gt.name', $li
 	$init_rows = $total_rows;
 
 	if ($hash !== false) {
+		cacti_log('Obtaining \'Graph Template\' cache', false, 'WEBUI', POLLER_VERBOSITY_HIGH);
 		$cached = get_cached_allowed_type($hash, $init_rows);
 
 		if (is_array($cached) && sizeof($cached)) {
+			cacti_log('Found Valid \'Graph Template\' priming cache', false, 'WEBUI', POLLER_VERBOSITY_HIGH);
 			return $cached;
 		}
 	}
@@ -2234,10 +2285,10 @@ function get_allowed_ajax_hosts($include_any = true, $include_none = true, $sql_
 
 	if (get_request_var('term') == '') {
 		if ($include_any) {
-			$return[] = array('label' => 'Any', 'value' => 'Any', 'id' => '-1');
+			$return[] = array('label' => __('Any'), 'value' => __('Any'), 'id' => '-1');
 		}
 		if ($include_none) {
-			$return[] = array('label' => 'None', 'value' => 'None', 'id' => '0');
+			$return[] = array('label' => __('None'), 'value' => __('None'), 'id' => '0');
 		}
 	}
 
@@ -2354,7 +2405,7 @@ function secpass_login_process($username) {
 
 				if (!$valid_pass) {
 					$failed = intval($user['failed_attempts']) + 1;
-					cacti_log('LOGIN: WARNING: User \'' . $username . '\' failed authentication, incrementing lockout (' . $failed . ' of ' . $max . ')',false,'AUTH', POLLER_VERBOSITY_LOW);
+					cacti_log('LOGIN: WARNING: User \'' . $username . '\' failed authentication, incrementing lockout (' . $failed . ' of ' . $max . ')', false, 'AUTH', POLLER_VERBOSITY_LOW);
 
 					if ($failed >= $max) {
 						db_execute_prepared("UPDATE user_auth
@@ -2407,9 +2458,9 @@ function secpass_login_process($username) {
 				AND enabled = 'on'",
 				array($username));
 
+			$message = __('Your Cacti administrator has forced complex passwords for logins and your current Cacti password does not match the new requirements.  Therefore, you must change your password now.');
+
 			display_custom_error_message($message);
-			header('Location: index.php?header=false');
-			exit;
 		}
 	}
 
@@ -2537,38 +2588,33 @@ function reset_user_perms($user_id) {
 		array($user_id));
 }
 
-/* user_perms_valid - checks to see if the admin has changed users permissions
+/* is_user_perms_valid - checks to see if the admin has changed users permissions
    @arg $user_id - (int) the id of the current user
    @returns - true if still valid, false otherwise */
-function user_perms_valid($user_id) {
+function is_user_perms_valid($user_id) {
 	global $config;
 
-	static $valid = 'null';
+	static $valid = NULL;
+	static $key = NULL;
 
-	if ($valid === 'null') {
-		$valid = true;
+	if (isset($_SESSION['sess_user_perms_key'])) {
+		$key = $_SESSION['sess_user_perms_key'];
+	} else {
+		$_SESSION['sess_user_perms_key'] = false;
+	}
 
+	if ($valid === NULL) {
 		if (cacti_version_compare($config['cacti_db_version'], '1.0.0', '>=')) {
 			$key = db_fetch_cell_prepared('SELECT reset_perms
 				FROM user_auth
 				WHERE id = ?',
 				array($user_id));
-
-			if (isset($_SESSION['sess_user_perms_key'])) {
-				if ($key != $_SESSION['sess_user_perms_key']) {
-					$valid = false;
-				}
-			}
-
-			$_SESSION['sess_user_perms_key'] = $key;
-		} else {
-			$_SESSION['sess_user_perms_key'] = $valid;
 		}
-	} else {
-		$valid = true;
-		$_SESSION['sess_user_perms_key'] = $valid;
 	}
 
+	$valid = ($_SESSION['sess_user_perms_key'] === $key);
+	$_SESSION['sess_user_perms_key'] = $key;
+
 	return $valid;
 }
 
