@@ -1193,6 +1193,15 @@ function is_menu_pick_active($menu_url) {
 
 	$menu_parts = array();
 
+	/* special case for host.php?action=edit&create=true */
+	if (strpos($_SERVER['REQUEST_URI'], 'host.php?action=edit&create=true') !== false) {
+		if (strpos($menu_url, 'host.php?action=edit&create=true') !== false) {
+			return true;
+		} else {
+			return false;
+		}
+	}
+
 	/* break out the URL and variables */
 	if (!is_array($url_array) || (is_array($url_array) && !cacti_sizeof($url_array))) {
 		$url_array = parse_url($_SERVER['REQUEST_URI']);
